#!/usr/bin/env bash

pushd random_binaries
  python ../corrupt.py -a -n 100 -o 1.txt 0.txt
  python ../corrupt.py -a -n 100 -o 2.txt 1.txt
  python ../corrupt.py -a -n 100 -o 3.txt 2.txt
  python ../corrupt.py -a -n 100 -o 4.txt 3.txt
popd
